# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-07-31 11:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fec_dbsync', '0015_misreportrequesttracking'),
    ]

    operations = [
        migrations.AddField(
            model_name='misreportrequesttracking',
            name='requester',
            field=models.CharField(default='', max_length=200),
        ),
    ]
