# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-06-04 14:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fec_dbsync', '0003_auto_20180604_0411'),
    ]

    operations = [
        migrations.AlterField(
            model_name='generalaccount',
            name='ACCT_STATUS',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='generalaccount',
            name='DPD_ASON_DATE',
            field=models.DateField(null=True),
        ),
        migrations.AlterField(
            model_name='generalaccount',
            name='PAYOFF_DATE',
            field=models.CharField(max_length=320, null=True),
        ),
    ]
