# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-06-11 04:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fec_dbsync', '0007_auto_20180608_0858'),
    ]

    operations = [
        migrations.AddField(
            model_name='roboidtview',
            name='DMD_FLOW_ID',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AddField(
            model_name='roboidtview',
            name='LATEFEE_STATUS_FLAG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AddField(
            model_name='roboidtview',
            name='SHDL_NUM',
            field=models.CharField(max_length=8, null=True),
        ),
    ]
